@@ -1,5 +1,5 @@
 """Names of data types in JSON schemas."""
-from jsonvl.utilities.venum import Venum
+from jsonvl._utilities.venum import Venum
 
 
 class Primitive(Venum):
