@@ -5,7 +5,14 @@ class Reserved:
     """Reserved words related to type definitions and constraints."""
 
     ALL = 'all'
-    ATTRIBUTES = 'attrs'
+    ATTRIBUTES = 'attr'
     CONSTRAINTS = 'cons'
+    DEFS = 'defs'
     ELEMENT = 'elem'
     TYPE = 'type'
+
+
+class ReservedSymbols:
+    """Reserved symbols related to type definitions and constraints."""
+
+    REF = '#'
