@@ -1,5 +1,5 @@
 """String formats."""
-from jsonvl.utilities.venum import Venum
+from jsonvl._utilities.venum import Venum
 
 
 class StringFormats(Venum):
