@@ -1,7 +1,7 @@
 """Module for jsonvl exceptions and error handling."""
 
+from jsonvl.errors._messages import ErrorMessages
 from jsonvl.errors.errors import JsonSchemaError, JsonValidationError
-from jsonvl.errors.messages import ErrorMessages
 
 
 __all__ = ['JsonSchemaError', 'JsonValidationError', 'ErrorMessages']
